@@ -52,6 +52,14 @@ class DBKeyNotFound(DragonflowException):
     message = _('DB Key not found, key=%(key)s')
 
 
+class ReferencedObjectNotFound(DragonflowException):
+    message = _('Referenced object not found. proxy=%(proxy)s')
+
+
+class CommandError(DragonflowException):
+    message = _("Non-existent fields are specified: %(non_existent_fields)s")
+
+
 class UnsupportedTransportException(DragonflowException):
     """
     An exception for cases when the given transport protocol (e.g. UDP, TCP) is
@@ -73,6 +81,10 @@ class NoRemoteIPProxyException(DragonflowException):
     message = _('The metadata request has no remote IP')
 
 
+class InvalidIPAddressException(DragonflowException):
+    message = _('The IP address %(key)s is invalid')
+
+
 class LogicalPortNotFoundByTunnelKey(DragonflowException):
     message = _('Could not find logical port with tunnel key %(key)')
 
@@ -81,3 +93,28 @@ class DFMultipleExceptions(exceptions.MultipleExceptions):
 
     def __str__(self):
         return ','.join(str(error) for error in self.inner_exceptions)
+
+
+class UnknownResourceException(DragonflowException):
+    message = _('Could not find lock id for resource type %(resource_type)')
+
+
+class InvalidDBHostConfiguration(DragonflowException):
+    message = _('The DB host string %(host)s is invalid.')
+
+
+class OutOfCookieSpaceException(DragonflowException):
+    message = _('Out of cookie space.')
+
+
+class MaskOverlapException(DragonflowException):
+    message = _('Cookie mask overlap for cookie %(app_name)s/%(name)s')
+
+
+class CookieOverflowExcpetion(DragonflowException):
+    message = _('Cookie overflow: '
+                'Value: %(cookie)s Offset: %(offset)s Mask: %(mask)s')
+
+
+class InvalidEtherTypeException(DragonflowException):
+    message = _('Unsupported ethertype: %(ethertype)')
