@@ -13,27 +13,17 @@
 
 import struct
 
+import netaddr
 from neutron.agent.common import utils
-from oslo_config import cfg
+from neutron_lib import constants as n_const
 from oslo_log import log
 from ryu.lib import addrconv
+from ryu.ofproto import ether
 
-from dragonflow._i18n import _LE
 from dragonflow.common import exceptions
-from dragonflow.controller.common import constants as const
-from dragonflow.controller.common import cookies
 
 LOG = log.getLogger(__name__)
 
-_aging_cookie = 0
-ACTIVE_PORT_DETECTION_APP = \
-    "active_port_detection_app.ActivePortDetectionApp"
-
-
-AGING_COOKIE_NAME = 'aging'
-AGING_COOKIE_LEN = 1
-cookies.register_cookie_bits(AGING_COOKIE_NAME, AGING_COOKIE_LEN)
-
 
 def ipv4_text_to_int(ip_text):
     try:
@@ -43,39 +33,12 @@ def ipv4_text_to_int(ip_text):
 
 
 def ipv6_text_to_short(ip_text):
-    if isinstance(ip_text, unicode):
-        ip_text = ip_text.encode('ascii', 'ignore')
     try:
         return list(struct.unpack('!8H', addrconv.ipv6.text_to_bin(ip_text)))
     except Exception:
         raise exceptions.InvalidIPAddressException(key=ip_text)
 
 
-def set_aging_cookie(c):
-    global _aging_cookie
-    _aging_cookie = c
-
-
-def get_aging_cookie():
-    return _aging_cookie
-
-
-def set_aging_cookie_bits(old_cookie, old_cookie_mask):
-    return cookies.get_cookie(AGING_COOKIE_NAME, _aging_cookie,
-                              old_cookie, old_cookie_mask)
-
-
-def get_xor_cookie(cookie):
-    return cookie ^ const.GLOBAL_INIT_AGING_COOKIE
-
-
-def check_active_port_detection_app():
-    apps_list = cfg.CONF.df.apps_list
-    if ACTIVE_PORT_DETECTION_APP in apps_list:
-        return True
-    return False
-
-
 def delete_conntrack_entries_by_filter(ethertype='IPv4', protocol=None,
                                        nw_src=None, nw_dst=None, zone=None):
     cmd = ['conntrack', '-D']
@@ -83,9 +46,9 @@ def delete_conntrack_entries_by_filter(ethertype='IPv4', protocol=None,
         cmd.extend(['-p', str(protocol)])
     cmd.extend(['-f', ethertype.lower()])
     if nw_src:
-        cmd.extend(['-s', nw_src])
+        cmd.extend(['-s', str(nw_src)])
     if nw_dst:
-        cmd.extend(['-d', nw_dst])
+        cmd.extend(['-d', str(nw_dst)])
     if zone:
         cmd.extend(['-w', str(zone)])
 
@@ -94,4 +57,35 @@ def delete_conntrack_entries_by_filter(ethertype='IPv4', protocol=None,
                       extra_ok_codes=[1])
         LOG.debug("Successfully executed conntrack command %s", cmd)
     except RuntimeError:
-        LOG.exception(_LE("Failed execute conntrack command %s"), cmd)
+        LOG.exception("Failed execute conntrack command %s", cmd)
+
+
+def ethertype_to_ip_version(ethertype):
+    if ethertype == n_const.IPv4:
+        return n_const.IP_VERSION_4
+    if ethertype == n_const.IPv6:
+        return n_const.IP_VERSION_6
+    raise exceptions.InvalidEtherTypeException(ethertype=ethertype)
+
+
+def get_eth_from_ip_version(ip_version):
+    """
+    Returns the eth_type that should be matched to the received ip
+
+    :param ip_version: IP version int in the format 4/6
+    """
+    match_items = {
+        (n_const.IP_VERSION_4): ether.ETH_TYPE_IP,
+        (n_const.IP_VERSION_6): ether.ETH_TYPE_IPV6
+    }
+    return match_items[ip_version]
+
+
+def get_port_match_list_from_port_range(port_range_min, port_range_max):
+    port_range = netaddr.IPRange(port_range_min, port_range_max)
+    ports_match_list = []
+    for cidr in port_range.cidrs():
+        port_num = int(cidr.network) & 0xffff
+        mask = int(cidr.netmask) & 0xffff
+        ports_match_list.append((port_num, mask))
+    return ports_match_list
