@@ -10,17 +10,15 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from contextlib import contextmanager
 from socket import timeout as SocketTimeout
 
-from contextlib import contextmanager
-import etcd
-import eventlet
+import etcd3gw as etcd
 from oslo_log import log
 import urllib3
 from urllib3 import connection
 from urllib3 import exceptions
 
-from dragonflow._i18n import _LE
 from dragonflow.common import exceptions as df_exceptions
 from dragonflow.db import db_api
 
@@ -88,21 +86,6 @@ def _error_catcher(self):
 urllib3.HTTPResponse._error_catcher = _error_catcher
 
 
-def _check_valid_host(host_str):
-    return ':' in host_str and host_str[-1] != ':'
-
-
-def _parse_hosts(hosts):
-    host_ports = []
-    for host_str in hosts:
-        if _check_valid_host(host_str):
-            host_port = host_str.strip().split(':')
-            host_ports.append((host_port[0], int(host_port[1])))
-        else:
-            LOG.error(_LE("The host string %s is invalid."), host_str)
-    return tuple(host_ports)
-
-
 class EtcdDbDriver(db_api.DbApi):
 
     def __init__(self):
@@ -110,76 +93,71 @@ class EtcdDbDriver(db_api.DbApi):
         self.client = None
         self.current_key = 0
         self.notify_callback = None
-        self.pool = eventlet.GreenPool(size=1)
 
     def initialize(self, db_ip, db_port, **args):
-        hosts = _parse_hosts(args['config'].remote_db_hosts)
-        if hosts:
-            self.client = etcd.Client(host=hosts, allow_reconnect=True)
-        else:
-            self.client = etcd.Client(host=db_ip, port=db_port)
-
-    def support_publish_subscribe(self):
-        return True
+        self.client = etcd.client(host=db_ip, port=db_port)
 
     def create_table(self, table):
         # Not needed in etcd
         pass
 
     def delete_table(self, table):
-        # Not needed in etcd
-        pass
+        self.client.delete_prefix(self._make_key(table))
+
+    @staticmethod
+    def _make_key(table, obj_id=None):
+        if obj_id:
+            key = '/{}/{}'.format(table, obj_id)
+        else:
+            key = '/{}/'.format(table)
+        return key
 
     def get_key(self, table, key, topic=None):
-        try:
-            return self.client.read('/' + table + '/' + key).value
-        except etcd.EtcdKeyNotFound:
-            raise df_exceptions.DBKeyNotFound(key=key)
+        value = self.client.get(self._make_key(table, key))
+        if len(value) > 0:
+            return value.pop()
+        raise df_exceptions.DBKeyNotFound(key=key)
 
     def set_key(self, table, key, value, topic=None):
-        self.client.write('/' + table + '/' + key, value)
+        self.client.put(self._make_key(table, key), value)
 
     def create_key(self, table, key, value, topic=None):
-        self.client.write('/' + table + '/' + key, value)
+        self.client.put(self._make_key(table, key), value)
 
     def delete_key(self, table, key, topic=None):
-        try:
-            self.client.delete('/' + table + '/' + key)
-        except etcd.EtcdKeyNotFound:
+        deleted = self.client.delete(self._make_key(table, key))
+        if not deleted:
             raise df_exceptions.DBKeyNotFound(key=key)
 
     def get_all_entries(self, table, topic=None):
         res = []
-        try:
-            directory = self.client.get("/" + table)
-        except etcd.EtcdKeyNotFound:
-            return res
-        for entry in directory.children:
-            if entry.value:
-                res.append(entry.value)
+        directory = self.client.get_prefix(self._make_key(table))
+        for entry in directory:
+            value = entry[0]
+            if value:
+                res.append(value)
         return res
 
     def get_all_keys(self, table, topic=None):
         res = []
-        try:
-            directory = self.client.get("/" + table)
-        except etcd.EtcdKeyNotFound:
-            raise df_exceptions.DBKeyNotFound(key=table)
-        for entry in directory.children:
+        directory = self.client.get_prefix(self._make_key(table))
+        for entry in directory:
             table_name_size = len(table) + 2
-            res.append(entry.key[table_name_size:])
+            key = entry[1]["key"]
+            res.append(key[table_name_size:])
         return res
 
     def _allocate_unique_key(self, table):
         key = '/unique_key/%s' % table
         prev_value = 0
         try:
-            prev_value = int(self.client.read(key).value)
-            self.client.test_and_set(key, str(prev_value + 1), str(prev_value))
+            prev_value = int(self.get_key('unique_key', table))
+            # FIXME(lihi): race-condition?
+            self.client.replace(key, str(prev_value), str(prev_value + 1))
             return prev_value + 1
-        except Exception:
+        except df_exceptions.DBKeyNotFound:
             if prev_value == 0:
-                self.client.write(key, "1", prevExist=False)
+                self.client.put(key, "1")
                 return 1
             raise
 
@@ -190,18 +168,6 @@ class EtcdDbDriver(db_api.DbApi):
             except Exception:
                 pass
 
-    def register_notification_callback(self, callback):
-        self.notify_callback = callback
-        self.pool.spawn_n(self._db_changes_updater)
-
-    def register_topic_for_notification(self, topic):
-        # TODO(gsagie) implement this
-        pass
-
-    def unregister_topic_for_notification(self, topic):
-        # TODO(gsagie) implement this
-        pass
-
     def process_ha(self):
         # Not needed in etcd
         pass
@@ -209,19 +175,3 @@ class EtcdDbDriver(db_api.DbApi):
     def set_neutron_server(self, is_neutron_server):
         # Not needed in etcd
         pass
-
-    def _db_changes_updater(self):
-        while True:
-            try:
-                entry = self.client.read('/', wait=True, recursive=True,
-                                         waitIndex=self.current_key,
-                                         timeout=ETCD_READ_TIMEOUT)
-                keys = entry.key.split('/')
-                self.notify_callback(keys[1], keys[2], entry.action,
-                                     entry.value, None)
-                self.current_key = entry.modifiedIndex + 1
-            except Exception as e:
-                if "Read timed out" not in e.message:
-                    LOG.warning(e)
-                    self.notify_callback(None, None, 'sync',
-                                         None, None)
