@@ -12,21 +12,19 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import eventlet
-from oslo_config import cfg
+import time
+
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
 import redis
 
-from dragonflow._i18n import _LE, _LW
-from dragonflow.common import common_params
+from dragonflow import conf as cfg
+from dragonflow.controller.common import constants
 from dragonflow.db.drivers import redis_mgt
 from dragonflow.db import pub_sub_api
 
 LOG = logging.getLogger(__name__)
 
-cfg.CONF.register_opts(common_params.df_opts, 'df')
-
 
 class RedisPubSub(pub_sub_api.PubSubApi):
 
@@ -43,7 +41,9 @@ class RedisPubSub(pub_sub_api.PubSubApi):
         return self.subscriber
 
 
-class RedisPublisherAgent(pub_sub_api.PublisherApi):
+class RedisPublisherAgent(pub_sub_api.PublisherAgentBase):
+
+    publish_retry_times = 5
 
     def __init__(self):
         super(RedisPublisherAgent, self).__init__()
@@ -59,6 +59,12 @@ class RedisPublisherAgent(pub_sub_api.PublisherApi):
             cfg.CONF.df.remote_db_port)
         self._update_client()
 
+    def close(self):
+        if self.remote:
+            self.client.connection_pool.disconnect()
+        self.client = None
+        self.remote = None
+
     def _update_client(self):
         if self.redis_mgt is not None:
             self.remote = self.redis_mgt.pubsub_select_node_idx()
@@ -74,28 +80,34 @@ class RedisPublisherAgent(pub_sub_api.PublisherApi):
         if self.remote is None:
             self._update_client()
 
-    def send_event(self, update, topic=None):
-        if topic:
-            update.topic = topic
-        local_topic = update.topic
-        local_topic = local_topic.encode('utf8')
-        data = pub_sub_api.pack_message(update.to_dict())
-        try:
-            if self.client is not None:
-                self.client.publish(local_topic, data)
-        except Exception as e:
-            LOG.exception(_LE("publish connection get exception "
-                              "%(e)s") % {'e': e})
-            self.redis_mgt.remove_node_from_master_list(self.remote)
+    def _sync_master_list(self):
+        LOG.info("publish connection old masterlist %s",
+                 self.redis_mgt.master_list)
+        result = self.redis_mgt.redis_get_master_list_from_syncstring(
+            redis_mgt.RedisMgt.global_sharedlist.raw)
+        LOG.info("publish connection new masterlist %s",
+                 self.redis_mgt.master_list)
+        if result:
             self._update_client()
+
+    def _send_event(self, data, topic):
+        ttl = self.publish_retry_times
+        alreadysync = False
+        while ttl > 0:
+            ttl -= 1
             try:
                 if self.client is not None:
-                    self.client.publish(local_topic, data)
+                    self.client.publish(topic, data)
+                    break
             except Exception:
+                if not alreadysync:
+                    self._sync_master_list()
+                    alreadysync = True
+                    LOG.exception("publish error remote:%(remote)s ",
+                                  {'remote': self.remote})
+                    continue
                 self.redis_mgt.remove_node_from_master_list(self.remote)
                 self._update_client()
-                LOG.exception(_LE("publish error remote:%(remote)s")
-                              % {'remote': self.remote})
 
     def set_publisher_for_failover(self, pub, callback):
         self.redis_mgt.set_publisher(pub, callback)
@@ -106,7 +118,7 @@ class RedisPublisherAgent(pub_sub_api.PublisherApi):
 
             self.redis_mgt.daemonize()
         else:
-            LOG.warning(_LW("redis mgt is none"))
+            LOG.warning("redis mgt is none")
 
 
 class RedisSubscriberAgent(pub_sub_api.SubscriberAgentBase):
@@ -119,6 +131,7 @@ class RedisSubscriberAgent(pub_sub_api.SubscriberAgentBase):
         self.plugin_updates_port = ""
         self.pub_sub = None
         self.redis_mgt = None
+        self.is_closed = True
 
     def initialize(self, callback):
         # find a subscriber server node and run daemon
@@ -127,6 +140,7 @@ class RedisSubscriberAgent(pub_sub_api.SubscriberAgentBase):
             cfg.CONF.df.remote_db_ip,
             cfg.CONF.df.remote_db_port)
         self._update_client()
+        self.is_closed = False
 
     def process_ha(self):
         # None means that subscriber connection should be updated.
@@ -146,11 +160,11 @@ class RedisSubscriberAgent(pub_sub_api.SubscriberAgentBase):
                 self.plugin_updates_port = ip_port[1]
                 self.pub_sub = self.client.pubsub()
 
-    def register_listen_address(self, uri):
-        super(RedisSubscriberAgent, self).register_listen_address(uri)
-
-    def unregister_listen_address(self, uri):
-        super(RedisSubscriberAgent, self).unregister_listen_address(uri)
+    def close(self):
+        self.redis_mgt = None
+        self.pub_sub.close()
+        self.pub_sub = None
+        self.is_closed = True
 
     def register_topic(self, topic):
         self.pub_sub.subscribe(topic)
@@ -165,11 +179,11 @@ class RedisSubscriberAgent(pub_sub_api.SubscriberAgentBase):
         if self.redis_mgt is not None:
             self.redis_mgt.register_ha_topic()
         else:
-            LOG.warning(_LW("redis mgt is none"))
+            LOG.warning("redis mgt is none")
 
     def run(self):
-        while True:
-            eventlet.sleep(0)
+        while not self.is_closed:
+            time.sleep(0)
             try:
                 if self.pub_sub is not None:
                     for data in self.pub_sub.listen():
@@ -178,36 +192,34 @@ class RedisSubscriberAgent(pub_sub_api.SubscriberAgentBase):
                         elif 'unsubscribe' == data['type']:
                             continue
                         elif 'message' == data['type']:
-                            message = pub_sub_api.unpack_message(data['data'])
-
-                            if message['table'] != 'ha':
-                                self.db_changes_callback(
-                                    message['table'],
-                                    message['key'],
-                                    message['action'],
-                                    message['value'],
-                                    message['topic'])
-                            else:
+                            # Redis managment module publishes node list
+                            # on topic 'redis'.
+                            # All other topics are for the user.
+                            if data['channel'] == 'redis':
                                 # redis ha message
+                                message = pub_sub_api.unpack_message(
+                                    data['data'])
                                 value = jsonutils.loads(message['value'])
                                 self.redis_mgt.redis_failover_callback(
                                     value)
+                            else:
+                                self._handle_incoming_event(data['data'])
                         else:
-                            LOG.warning(_LW("receive unknown message in "
-                                            "subscriber %(type)s")
-                                        % {'type': data['type']})
+                            LOG.warning("receive unknown message in "
+                                        "subscriber %(type)s",
+                                        {'type': data['type']})
 
                 else:
-                    LOG.warning(_LW("pubsub lost connection %(ip)s:"
-                                    "%(port)s")
-                                % {'ip': self.ip,
-                                   'port': self.plugin_updates_port})
-                    eventlet.sleep(1)
+                    LOG.warning("pubsub lost connection %(ip)s:"
+                                "%(port)s",
+                                {'ip': self.ip,
+                                 'port': self.plugin_updates_port})
+                    time.sleep(1)
 
             except Exception as e:
-                LOG.warning(_LW("subscriber listening task lost "
-                                "connection "
-                                "%(e)s") % {'e': e})
+                LOG.warning("subscriber listening task lost "
+                            "connection "
+                            "%(e)s", {'e': e})
 
                 try:
                     connection = self.pub_sub.connection
@@ -215,8 +227,9 @@ class RedisSubscriberAgent(pub_sub_api.SubscriberAgentBase):
                     self.pub_sub.on_connect(connection)
                     # self.db_changes_callback(None, None, 'sync', None, None)
                     # notify restart
-                    self.db_changes_callback(None, None, 'dbrestart', False,
-                                             None)
+                    self.db_changes_callback(None, None,
+                                             constants.CONTROLLER_DBRESTART,
+                                             False, None)
                 except Exception:
                     self.redis_mgt.remove_node_from_master_list(self.remote)
                     self._update_client()
@@ -224,12 +237,12 @@ class RedisSubscriberAgent(pub_sub_api.SubscriberAgentBase):
                     if self.remote is not None:
                         # to re-subscribe
                         self.register_hamsg_for_db()
-                        self.db_changes_callback(None, None, 'dbrestart',
-                                                 True, None)
+                        self.db_changes_callback(
+                            None, None, constants.CONTROLLER_DBRESTART, True,
+                            None)
                     else:
-                        LOG.warning(_LW("there is no more db node "
-                                        "available"))
+                        LOG.warning("there is no more db node available")
 
-                    LOG.exception(_LE("reconnect error %(ip)s:%(port)s")
-                                  % {'ip': self.ip,
-                                     'port': self.plugin_updates_port})
+                    LOG.exception("reconnect error %(ip)s:%(port)s",
+                                  {'ip': self.ip,
+                                   'port': self.plugin_updates_port})
