@@ -21,9 +21,6 @@ from dragonflow.tests.fullstack import test_objects as objects
 
 class TestOVSFlowsForDHCP(test_base.DFTestBase):
 
-    def setUp(self):
-        super(TestOVSFlowsForDHCP, self).setUp()
-
     def get_dhcp_ip(self, network_id, subnet_id):
         ports = self.neutron.list_ports(network_id=network_id)
         ports = ports['ports']
@@ -44,9 +41,9 @@ class TestOVSFlowsForDHCP(test_base.DFTestBase):
                      ',tp_dst=' + str(constants.DHCP_SERVER_PORT)
         for flow in flows:
             if (flow['table'] == str(constants.SERVICES_CLASSIFICATION_TABLE)
-                and flow['actions'] == goto_dhcp):
+                    and flow['actions'] == goto_dhcp):
                 if ('udp,dl_dst=' + constants.BROADCAST_MAC + dhcp_ports
-                    in flow['match']):
+                        in flow['match']):
                     found_dhcp_cast_flow = True
                     break
         self.assertTrue(found_dhcp_cast_flow)
@@ -57,11 +54,11 @@ class TestOVSFlowsForDHCP(test_base.DFTestBase):
         network = self.store(objects.NetworkTestObj(self.neutron, self.nb_api))
         network_id = network.create()
         subnet = {'network_id': network_id,
-            'cidr': '10.10.254.0/24',
-            'gateway_ip': '10.10.254.1',
-            'ip_version': 4,
-            'name': 'subnet-test',
-            'enable_dhcp': True}
+                  'cidr': '10.10.254.0/24',
+                  'gateway_ip': '10.10.254.1',
+                  'ip_version': 4,
+                  'name': 'subnet-test',
+                  'enable_dhcp': True}
         subnet = self.neutron.create_subnet({'subnet': subnet})
         subnet_id = subnet['subnet']['id']
         dhcp_ip = utils.wait_until_is_and_return(
@@ -72,7 +69,7 @@ class TestOVSFlowsForDHCP(test_base.DFTestBase):
             flows_before_change, dhcp_ip))
         utils.wait_until_true(
             lambda: utils.check_dhcp_ip_rule(ovs.dump(self.integration_bridge),
-                                         dhcp_ip),
+                                             dhcp_ip),
             exception=Exception('DHCP ip was not found in OpenFlow rules'),
             timeout=5
         )
@@ -90,11 +87,11 @@ class TestOVSFlowsForDHCP(test_base.DFTestBase):
         network = self.store(objects.NetworkTestObj(self.neutron, self.nb_api))
         network_id = network.create()
         subnet = {'network_id': network_id,
-            'cidr': '10.20.0.0/24',
-            'gateway_ip': '10.20.0.1',
-            'ip_version': 4,
-            'name': 'subnet-test',
-            'enable_dhcp': False}
+                  'cidr': '10.20.0.0/24',
+                  'gateway_ip': '10.20.0.1',
+                  'ip_version': 4,
+                  'name': 'subnet-test',
+                  'enable_dhcp': False}
         subnet = self.neutron.create_subnet({'subnet': subnet})
         subnet_id = subnet['subnet']['id']
         time.sleep(const.DEFAULT_CMD_TIMEOUT)
@@ -111,14 +108,14 @@ class TestOVSFlowsForDHCP(test_base.DFTestBase):
         self.assertFalse(utils.check_dhcp_ip_rule(flows_after_change, dhcp_ip))
         utils.wait_until_true(
             lambda: utils.check_dhcp_ip_rule(ovs.dump(self.integration_bridge),
-                                         dhcp_ip),
+                                             dhcp_ip),
             exception=Exception('DHCP ip was not found in OpenFlow rules'),
             timeout=5
         )
         network.close()
         utils.wait_until_none(
             lambda: utils.check_dhcp_ip_rule(ovs.dump(self.integration_bridge),
-                                         dhcp_ip),
+                                             dhcp_ip),
             exception=Exception('DHCP IP was not removed from OpenFlow rules'),
             timeout=30
         )
@@ -130,11 +127,11 @@ class TestOVSFlowsForDHCP(test_base.DFTestBase):
         network = self.store(objects.NetworkTestObj(self.neutron, self.nb_api))
         network_id = network.create()
         subnet = {'network_id': network_id,
-            'cidr': '10.30.0.0/24',
-            'gateway_ip': '10.30.0.1',
-            'ip_version': 4,
-            'name': 'subnet-test',
-            'enable_dhcp': True}
+                  'cidr': '10.30.0.0/24',
+                  'gateway_ip': '10.30.0.1',
+                  'ip_version': 4,
+                  'name': 'subnet-test',
+                  'enable_dhcp': True}
         subnet = self.neutron.create_subnet({'subnet': subnet})
         subnet_id = subnet['subnet']['id']
         router_id = router.create()
@@ -155,7 +152,7 @@ class TestOVSFlowsForDHCP(test_base.DFTestBase):
         network.close()
         utils.wait_until_none(
             lambda: utils.check_dhcp_ip_rule(ovs.dump(self.integration_bridge),
-                                         dhcp_ip),
+                                             dhcp_ip),
             exception=Exception('DHCP IP was not removed from OpenFlow rules'),
             timeout=30
         )
