@@ -10,14 +10,20 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import netaddr
 import time
 
+import netaddr
 from neutron.agent.common import utils as agent_utils
+from neutron_lib import constants as n_const
 from neutronclient.common import exceptions
 from oslo_log import log
 
-from dragonflow._i18n import _LW
+from dragonflow.db.models import bgp
+from dragonflow.db.models import l2
+from dragonflow.db.models import l3
+from dragonflow.db.models import qos
+from dragonflow.db.models import secgroups
+
 from dragonflow.tests.common import clients
 from dragonflow.tests.common import constants as const
 from dragonflow.tests.common import utils
@@ -32,9 +38,9 @@ def find_first_network(nclient, params):
     if networks_count == 0:
         return None
     if networks_count > 1:
-        message = _LW("More than one network (%(count)d) found matching: "
-            "%(args)s")
-        LOG.warning(message % {'args': params, 'count': networks_count})
+        message = ("More than one network (%(count)d) found matching: "
+                   "%(args)s")
+        LOG.warning(message, {'args': params, 'count': networks_count})
     return networks[0]
 
 
@@ -48,6 +54,16 @@ def get_port_by_mac(neutron, vm_mac):
     return ports[0]
 
 
+def get_port_by_id(neutron, port_id):
+    ports = neutron.list_ports(id=port_id)
+    if not ports:
+        return None
+    ports = ports.get('ports')
+    if not ports:
+        return None
+    return ports[0]
+
+
 class RouterTestObj(object):
 
     def __init__(self, neutron, nb_api):
@@ -69,6 +85,7 @@ class RouterTestObj(object):
     def close(self):
         if self.closed or self.router_id is None:
             return
+        self.update(router={"routes": None})
         ports = self.neutron.list_ports(device_id=self.router_id)
         ports = ports['ports']
         for port in ports:
@@ -85,7 +102,7 @@ class RouterTestObj(object):
         self.closed = True
 
     def exists(self):
-        router = self.nb_api.get_router(self.router_id)
+        router = self.nb_api.get(l3.LogicalRouter(id=self.router_id))
         if router:
             return True
         return False
@@ -130,7 +147,8 @@ class SecGroupTestObj(object):
         self.closed = True
 
     def exists(self):
-        secgroup = self.nb_api.get_security_group(self.secgroup_id)
+        sg_obj = secgroups.SecurityGroup(id=self.secgroup_id)
+        secgroup = self.nb_api.get(sg_obj)
         if secgroup:
             return True
         return False
@@ -146,10 +164,11 @@ class SecGroupTestObj(object):
         self.neutron.delete_security_group_rule(secrule_id)
 
     def rule_exists(self, secrule_id):
-        secgroup = self.nb_api.get_security_group(self.secgroup_id)
+        sg_obj = secgroups.SecurityGroup(id=self.secgroup_id)
+        secgroup = self.nb_api.get(sg_obj)
         if secgroup:
-            for rule in secgroup.get_rules():
-                if rule.get_id() == secrule_id:
+            for rule in secgroup.rules:
+                if rule.id == secrule_id:
                     return True
         return False
 
@@ -167,7 +186,7 @@ class NetworkTestObj(object):
     def get_network(self):
         return self.network
 
-    def create(self, network={'name': 'mynetwork1', 'admin_state_up': True}):
+    def create(self, network={'name': 'mynetwork', 'admin_state_up': True}):
         self.network = self.neutron.create_network({'network': network})
         self.network_id = self.network['network']['id']
         self.topic = self.network['network']['tenant_id']
@@ -198,7 +217,7 @@ class NetworkTestObj(object):
         return self.topic
 
     def exists(self):
-        netobj = self.nb_api.get_lswitch(self.network_id)
+        netobj = self.nb_api.get(l2.LogicalSwitch(id=self.network_id))
         if netobj:
             return True
         return False
@@ -214,7 +233,7 @@ class ExternalNetworkTestObj(NetworkTestObj):
         net_id = super(ExternalNetworkTestObj, self).create(network)
         subnet = SubnetTestObj(self.neutron, self.nb_api, net_id)
         subnet.create({'cidr': self.GW_CIDR,
-                       'ip_version': 4,
+                       'ip_version': n_const.IP_VERSION_4,
                        'enable_dhcp': False,
                        'network_id': net_id})
         # Hardcode the external bridge name here, as it is the
@@ -263,7 +282,7 @@ class VMTestObj(object):
 
     def create(self, network=None, script=None, security_groups=None,
                net_address=None):
-        image = self.nova.images.find(name="cirros-0.3.4-x86_64-uec")
+        image = self.nova.glance.find_image("cirros-0.3.5-x86_64-disk")
         self.parent.assertIsNotNone(image)
         flavor = self.nova.flavors.find(name="m1.tiny")
         self.parent.assertIsNotNone(flavor)
@@ -274,9 +293,10 @@ class VMTestObj(object):
         self.parent.assertIsNotNone(net_id)
         nic = {'net-id': net_id}
         if net_address:
-            if netaddr.IPAddress(net_address).version == 4:
+            if netaddr.IPAddress(net_address).version == n_const.IP_VERSION_4:
                 nic['v4-fixed-ip'] = net_address
-            elif netaddr.IPAddress(net_address).version == 6:
+            elif netaddr.IPAddress(net_address).version == \
+                    n_const.IP_VERSION_6:
                 nic['v6-fixed-ip'] = net_address
         nics = [nic]
         self.server = self.nova.servers.create(
@@ -342,7 +362,7 @@ class VMTestObj(object):
         ips = self.nova.servers.ips(self.server)
         for id, network in ips.items():
             for ip in network:
-                if int(ip['version']) == 4:
+                if int(ip['version']) == n_const.IP_VERSION_4:
                     return ip['addr']
         return None
 
@@ -382,14 +402,10 @@ class SubnetTestObj(object):
         return subnet['subnet']
 
     def get_subnet(self):
-        network = self.nb_api.get_lswitch(self.network_id)
+        network = self.nb_api.get(l2.LogicalSwitch(id=self.network_id))
         if not network:
             return None
-        subnets = network.get_subnets()
-        for subnet in subnets:
-            if subnet.get_id() == self.subnet_id:
-                return subnet
-        return None
+        return network.find_subnet(self.subnet_id)
 
     def exists(self):
         subnet = self.get_subnet()
@@ -437,7 +453,7 @@ class PortTestObj(object):
         return port['port']
 
     def get_logical_port(self):
-        return self.nb_api.get_logical_port(self.port_id)
+        return self.nb_api.get(l2.LogicalPort(id=self.port_id))
 
     def exists(self):
         port = self.get_logical_port()
@@ -479,13 +495,10 @@ class FloatingipTestObj(object):
         self.closed = True
 
     def get_floatingip(self):
-        return self.nb_api.get_floatingip(self.floatingip_id)
+        return self.nb_api.get(l3.FloatingIp(id=self.floatingip_id))
 
     def exists(self):
-        floatingip = self.nb_api.get_floatingip(self.floatingip_id)
-        if floatingip:
-            return True
-        return False
+        return self.get_floatingip() is not None
 
     def wait_until_fip_active(self, timeout=const.DEFAULT_CMD_TIMEOUT,
                               sleep=1, exception=None):
@@ -524,7 +537,251 @@ class QosPolicyTestObj(object):
         self.closed = True
 
     def exists(self):
-        qospolicy = self.nb_api.get_qos_policy(self.policy_id)
+        qospolicy = self.nb_api.get(qos.QosPolicy(id=self.policy_id))
         if qospolicy:
             return True
         return False
+
+
+class BGPPeerTestObj(object):
+    def __init__(self, neutron, nb_api):
+        self.peer_id = None
+        self.neutron = neutron
+        self.nb_api = nb_api
+        self.closed = False
+
+    def create(self, bgp_peer={'name': "peer1",
+                               'peer_ip': "172.24.4.100",
+                               'remote_as': 4321,
+                               'auth_type': 'none'}):
+        bgp_peer = self.neutron.create_bgp_peer({'bgp_peer': bgp_peer})
+        self.peer_id = bgp_peer['bgp_peer']['id']
+        return self.peer_id
+
+    def close(self):
+        if self.closed or self.peer_id is None:
+            return
+        self.neutron.delete_bgp_peer(self.peer_id)
+        self.closed = True
+
+    def exists(self):
+        bgp_peer = self.nb_api.get(bgp.BGPPeer(id=self.peer_id))
+        return bool(bgp_peer)
+
+
+class BGPSpeakerTestObj(object):
+    def __init__(self, neutron, nb_api):
+        self.speaker_id = None
+        self.neutron = neutron
+        self.nb_api = nb_api
+        self.closed = False
+
+    def create(self, bgp_speaker={'name': 'speaker1',
+                                  'local_as': 1234,
+                                  'ip_version': 4}):
+        bgp_speaker = self.neutron.create_bgp_speaker(
+            {'bgp_speaker': bgp_speaker})
+        self.speaker_id = bgp_speaker['bgp_speaker']['id']
+        return self.speaker_id
+
+    def add_peer(self, peer_id):
+        self.neutron.add_peer_to_bgp_speaker(self.speaker_id,
+                                             {'bgp_peer_id': peer_id})
+
+    def remove_peer(self, peer_id):
+        self.neutron.remove_peer_from_bgp_speaker(self.speaker_id,
+                                                  {'bgp_peer_id': peer_id})
+
+    def add_network(self, network_id):
+        self.neutron.add_network_to_bgp_speaker(self.speaker_id,
+                                                {'network_id': network_id})
+
+    def remove_network(self, network_id):
+        self.neutron.remove_network_from_bgp_speaker(
+            self.speaker_id, {'network_id': network_id})
+
+    def close(self):
+        if self.closed or self.speaker_id is None:
+            return
+        self.neutron.delete_bgp_speaker(self.speaker_id)
+        self.closed = True
+
+    def get_nb_bgp_speaker(self):
+        return self.nb_api.get(bgp.BGPSpeaker(id=self.speaker_id))
+
+    def exists(self):
+        bgp_speaker = self.nb_api.get(bgp.BGPSpeaker(id=self.speaker_id))
+        return bool(bgp_speaker)
+
+
+class AddressScopeTestObj(object):
+    def __init__(self, neutron, nb_api):
+        self.address_scope_id = None
+        self.neutron = neutron
+        self.nb_api = nb_api
+        self.closed = False
+
+    def create(self, address_scope={'name': "scope1",
+                                    'ip_version': 4}):
+        address_scope = self.neutron.create_address_scope(
+            {'address_scope': address_scope})
+        self.address_scope_id = address_scope['address_scope']['id']
+        return self.address_scope_id
+
+    def close(self):
+        if self.closed or self.address_scope_id is None:
+            return
+        self.neutron.delete_address_scope(self.address_scope_id)
+        self.closed = True
+
+
+class SubnetPoolTestObj(object):
+    def __init__(self, neutron, nb_api):
+        self.subnetpool_id = None
+        self.neutron = neutron
+        self.nb_api = nb_api
+        self.closed = False
+
+    def create(self, subnetpool):
+        subnetpool = self.neutron.create_subnetpool(
+            {'subnetpool': subnetpool})
+        self.subnetpool_id = subnetpool['subnetpool']['id']
+        return self.subnetpool_id
+
+    def close(self):
+        if self.closed or self.subnetpool_id is None:
+            return
+        self.neutron.delete_subnetpool(self.subnetpool_id)
+        self.closed = True
+
+
+class ChildPortSegmentationTestObj(object):
+    def __init__(self, neutron, nb_api):
+        self.neutron = neutron
+        self.nb_api = nb_api
+        self.closed = False
+        self.trunk = None
+
+    def create(self, parent_id, child_id, type_, id_):
+        if not self.trunk:
+            trunk_dict = {'port_id': parent_id}
+            result = self.neutron.create_trunk({'trunk': trunk_dict})
+            self.trunk = result['trunk']
+        self.subport = {'segmentation_type': type_,
+                        'segmentation_id': id_,
+                        'port_id': child_id}
+        self.neutron.trunk_add_subports(
+                self.trunk['id'], {'sub_ports': [self.subport]})
+        return self.subport
+
+    def close(self, keep_trunk=False):
+        self.neutron.trunk_remove_subports(
+               self.trunk['id'],
+               {'sub_ports': [self.subport],
+                'tenant_id': self.trunk['tenant_id']})
+        if not keep_trunk:
+            self.neutron.delete_trunk(self.trunk['id'])
+
+
+class PortPairTestObj(object):
+    def __init__(self, neutron, nb_api):
+        self.portpair_id = None
+        self.neutron = neutron
+        self.nb_api = nb_api
+        self.closed = False
+
+    def create(self, portpair):
+        new_portpair = self.neutron.create_port_pair({'port_pair': portpair})
+        self.portpair_id = new_portpair['port_pair']['id']
+        return self.portpair_id
+
+    def create_from_ports(self, ingress, egress, type_='mpls'):
+        self.create({
+            'ingress': ingress.port.port_id,
+            'egress': egress.port.port_id,
+            'service_function_parameters': {
+                'correlation': type_,
+            },
+        })
+        self.ingress = ingress
+        self.egress = egress
+
+    def close(self):
+        if self.closed or self.portpair_id is None:
+            return
+        self.neutron.delete_port_pair(self.portpair_id)
+        self.portpair_id = None
+
+
+class PortPairGroupTestObj(object):
+    def __init__(self, neutron, nb_api):
+        self.portpairgroup_id = None
+        self.neutron = neutron
+        self.nb_api = nb_api
+        self.closed = False
+
+    def create(self, portpairgroup):
+        new_ppg = self.neutron.create_port_pair_group(
+            {'port_pair_group': portpairgroup})
+        self.portpairgroup_id = new_ppg['port_pair_group']['id']
+        return self.portpairgroup_id
+
+    def create_from_portpairs(self, pps):
+        self.create({
+            'port_pairs': [pp.portpair_id for pp in pps],
+        })
+        self.port_pairs = pps
+
+    def close(self):
+        if self.closed or self.portpairgroup_id is None:
+            return
+        self.neutron.delete_port_pair_group(self.portpairgroup_id)
+        self.portpairgroup_id = None
+
+
+class PortChainTestObj(object):
+    def __init__(self, neutron, nb_api):
+        self.portchain_id = None
+        self.neutron = neutron
+        self.nb_api = nb_api
+        self.closed = False
+
+    def create(self, portchain):
+        new_portchain = self.neutron.create_port_chain(
+            {'port_chain': portchain})
+        self.portchain_id = new_portchain['port_chain']['id']
+        return self.portchain_id
+
+    def create_from_fcs_ppgs(self, fcs, ppgs):
+        self.create({
+            'flow_classifiers': [fc.flowclassifier_id for fc in fcs],
+            'port_pair_groups': [ppg.portpairgroup_id for ppg in ppgs],
+        })
+        self.flow_classifiers = fcs
+        self.port_pair_groups = ppgs
+
+    def close(self):
+        if self.closed or self.portchain_id is None:
+            return
+        self.neutron.delete_port_chain(self.portchain_id)
+        self.portchain_id = None
+
+
+class FlowClassifierTestObj(object):
+    def __init__(self, neutron, nb_api):
+        self.flowclassifier_id = None
+        self.neutron = neutron
+        self.nb_api = nb_api
+        self.closed = False
+
+    def create(self, flowclassifier):
+        new_flowclassifier = self.neutron.create_flow_classifier(
+            {'flow_classifier': flowclassifier})
+        self.flowclassifier_id = new_flowclassifier['flow_classifier']['id']
+        return self.flowclassifier_id
+
+    def close(self):
+        if self.closed or self.flowclassifier_id is None:
+            return
+        self.neutron.delete_flow_classifier(self.flowclassifier_id)
+        self.flowclassifier_id = None
