@@ -11,14 +11,15 @@
 #    under the License.
 
 import random
-import six
 import time
 
 from oslo_config import cfg
 from oslo_serialization import jsonutils
+import six
 
 from dragonflow.common import utils as df_utils
 from dragonflow.db import db_common
+from dragonflow.db.models import core
 from dragonflow.db import pub_sub_api
 from dragonflow.tests.common import constants as const
 from dragonflow.tests.common import utils as test_utils
@@ -34,26 +35,17 @@ class Namespace(object):
 
 
 class PubSubTestBase(test_base.DFTestBase):
-    def _get_publisher(self, pubsub_driver_name):
-        pub_sub_driver = df_utils.load_driver(
-            pubsub_driver_name,
-            df_utils.DF_PUBSUB_DRIVER_NAMESPACE)
-        publisher = pub_sub_driver.get_publisher()
-        publisher.initialize()
-        return publisher
-
-    def get_publisher(self):
-        if cfg.CONF.df.pub_sub_use_multiproc:
-            pubsub_driver_name = cfg.CONF.df.pub_sub_multiproc_driver
-        else:
-            pubsub_driver_name = cfg.CONF.df.pub_sub_driver
-        return self._get_publisher(pubsub_driver_name)
-
     def get_server_publisher(self, bind_address="127.0.0.1", port=12345):
-        cfg.CONF.df.publisher_port = str(port)
-        cfg.CONF.df.publisher_bind_address = bind_address
+        cfg.CONF.set_override('publisher_port', port, group='df')
+        cfg.CONF.set_override('publisher_bind_address',
+                              bind_address, group='df')
         return self._get_publisher(cfg.CONF.df.pub_sub_driver)
 
+    def stop_publisher(self, publisher):
+        if publisher:
+            publisher.close()
+            publisher = None
+
     def get_subscriber(self, callback):
         pub_sub_driver = df_utils.load_driver(
             cfg.CONF.df.pub_sub_driver,
@@ -67,9 +59,9 @@ class PubSubTestBase(test_base.DFTestBase):
             cfg.CONF.df.publisher_port
         )
         subscriber.register_listen_address(uri)
-        publishers = self.nb_api.get_publishers()
+        publishers = self.nb_api.get_all(core.Publisher)
         for publisher in publishers:
-            subscriber.register_listen_address(publisher.get_uri())
+            subscriber.register_listen_address(publisher.uri)
         subscriber.daemonize()
         return subscriber
 
@@ -121,7 +113,7 @@ class TestPubSub(PubSubTestBase):
         self.assertNotEqual(local_event_num, events_num)
         if cfg.CONF.df.enable_selective_topology_distribution:
             subscriber.unregister_topic(topic)
-        subscriber.stop()
+        subscriber.close()
         self.assertFalse(network.exists())
 
     def test_pub_sub_update_port(self):
@@ -172,7 +164,7 @@ class TestPubSub(PubSubTestBase):
         self.assertNotEqual(local_event_num, events_num)
         if cfg.CONF.df.enable_selective_topology_distribution:
             subscriber.unregister_topic(topic)
-        subscriber.stop()
+        subscriber.close()
         self.assertFalse(network.exists())
 
     def test_pub_sub_event_number_different_port(self):
@@ -208,7 +200,8 @@ class TestPubSub(PubSubTestBase):
         time.sleep(const.DEFAULT_CMD_TIMEOUT)
 
         self.assertEqual(local_events_num + 100, ns.events_num)
-        subscriber.stop()
+        subscriber.close()
+        self.stop_publisher(publisher)
 
     def test_pub_sub_add_topic(self):
         if not self.do_test:
@@ -253,7 +246,8 @@ class TestPubSub(PubSubTestBase):
         subscriber.unregister_topic(topic)
         publisher.send_event(update, topic)
         self.assertIsNone(self.events_action_t)
-        subscriber.stop()
+        subscriber.close()
+        self.stop_publisher(publisher)
 
     def test_pub_sub_register_addr(self):
         if not self.do_test:
@@ -296,6 +290,9 @@ class TestPubSub(PubSubTestBase):
         publisher2.send_event(update)
         time.sleep(const.DEFAULT_CMD_TIMEOUT)
         self.assertEqual(ns.events_action, action)
+        subscriber.close()
+        self.stop_publisher(publisher)
+        self.stop_publisher(publisher2)
 
 
 class TestMultiprocPubSub(PubSubTestBase):
@@ -311,11 +308,13 @@ class TestMultiprocPubSub(PubSubTestBase):
             "TestMultiprocPubSub value",
             topic=db_common.SEND_ALL_TOPIC,
         )
+        self.publisher = None
         self.subscriber = None
 
     def tearDown(self):
         if self.subscriber:
-            self.subscriber.stop()
+            self.subscriber.close()
+        self.stop_publisher(self.publisher)
         super(TestMultiprocPubSub, self).tearDown()
 
     def _verify_event(self, table, key, action, value, topic):
@@ -331,7 +330,8 @@ class TestMultiprocPubSub(PubSubTestBase):
         if not self.do_test:
             return
         self.event_received = False
-        cfg.CONF.df.publisher_multiproc_socket = '/tmp/ipc_test_socket'
+        cfg.CONF.set_override('publisher_multiproc_socket',
+                              '/tmp/ipc_test_socket', group='df')
         pub_sub_driver = df_utils.load_driver(
             cfg.CONF.df.pub_sub_multiproc_driver,
             df_utils.DF_PUBSUB_DRIVER_NAMESPACE)
@@ -342,7 +342,7 @@ class TestMultiprocPubSub(PubSubTestBase):
         self.subscriber.daemonize()
         publisher.send_event(self.event)
         test_utils.wait_until_true(lambda: self.event_received)
-        self.subscriber.stop()
+        self.subscriber.close()
         self.subscriber = None
 
 
@@ -364,7 +364,8 @@ class TestDbTableMonitors(PubSubTestBase):
     def tearDown(self):
         if self.do_test:
             self.monitor.stop()
-            self.subscriber.stop()
+            self.subscriber.close()
+        self.stop_publisher(self.publisher)
         super(TestDbTableMonitors, self).tearDown()
 
     def _db_change_callback(self, table, key, action, value, topic):
