@@ -15,6 +15,7 @@
 
 import mock
 
+from dragonflow.common import exceptions
 from dragonflow.db.drivers import redis_db_driver
 from dragonflow.tests import base as tests_base
 
@@ -44,14 +45,14 @@ class TestRedisDB(tests_base.BaseTestCase):
         self.RedisDbDriver._get_client = mock.Mock(return_value=client)
         self.RedisDbDriver._sync_master_list = mock.Mock()
         self.RedisDbDriver.clients[0] = client
-        client.keys.return_value = 'a'
-        client.mget.return_value = 'value'
+        client.keys.return_value = ['a']
+        client.mget.return_value = ['value']
         client.execute_command.return_value = 'value'
         redis_mgt = mock.Mock()
         self.RedisDbDriver.redis_mgt = redis_mgt
         redis_mgt.get_ip_by_key.return_value = '0.0.0.0:1000'
 
-        #test get_key
+        # test get_key
         result = self.RedisDbDriver.get_key('table', 'key')
         self.assertEqual('value', result)
         redis_mgt.get_ip_by_key.assert_called_with('a')
@@ -65,6 +66,26 @@ class TestRedisDB(tests_base.BaseTestCase):
         local_key = '{table.topic}.key'
         redis_mgt.get_ip_by_key.assert_called_with(local_key)
 
+        with mock.patch(
+            'dragonflow.db.drivers.redis_db_driver.RedisDbDriver._execute_cmd',
+            return_value=None,
+        ):
+            self.assertRaises(
+                exceptions.DBKeyNotFound,
+                self.RedisDbDriver.get_key,
+                'table', 'key', 'topic',
+            )
+
+        with mock.patch(
+            'dragonflow.db.drivers.redis_db_driver.RedisDbDriver._execute_cmd',
+            side_effect=RuntimeError,
+        ):
+            self.assertRaises(
+                exceptions.DBKeyNotFound,
+                self.RedisDbDriver.get_key,
+                'table', 'key', 'topic',
+            )
+
         # test get_all_entries
         result = self.RedisDbDriver.get_all_entries('table')
         self.assertEqual(['value'], result)
@@ -75,7 +96,7 @@ class TestRedisDB(tests_base.BaseTestCase):
         redis_mgt.get_ip_by_key.assert_called_with('a')
 
         result = self.RedisDbDriver.get_all_entries('table', 'topic')
-        self.assertEqual(['v', 'a', 'l', 'u', 'e'], result)
+        self.assertEqual(['value'], result)
         local_key = '{table.topic}.*'
         redis_mgt.get_ip_by_key.assert_called_with(local_key)
 
